gchecky.controller.ControllerLevel_1

Package gchecky :: Module controller :: Class ControllerLevel_1 |
[hide private]
[frames] | no frames]

# Class ControllerLevel_1

source code

    object --+
             |
            ControllerLevel_1

Known Subclasses:
  ControllerLevel_2

Instance Methods | [hide private]
__init__(self, vendor_id, merchant_key, is_sandbox=True, currency=`'``USD``'`) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
_get_url(self, tag, diagnose) | source code
get_client_post_cart_url(self, diagnose) | source code
get_server_post_cart_url(self, diagnose) | source code
get_checkout_button_url(self, diagnose) | source code
get_cart_post_button(self, diagnose) | source code
get_order_processing_url(self, diagnose) | source code
get_client_donation_url(self, diagnose) | source code
get_server_donation_url(self, diagnose) | source code
get_donation_button_url(self, diagnose) | source code
create_HMAC_SHA_signature(self, xml_text) | source code
prepare_order(self, order, order_id=None, diagnose=False) | source code
prepare_donation(self, order, order_id=None, diagnose=False) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
| __MERCHANT_BUTTON = ``'``MERCHANT_BUTTON``'``
| __CLIENT_POST_CART = ``'``CLIENT_POST_CART``'``
| __SERVER_POST_CART = ``'``SERVER_POST_CART``'``
| __ORDER_PROCESSING = ``'``ORDER_PROCESSING``'``
| __CLIENT_DONATION = ``'``CLIENT_DONATION``'``
| __SERVER_DONATION = ``'``SERVER_DONATION``'``
| __DONATION_BUTTON = ``'``DONATION_BUTTON``'``
| __SANDBOX_URLS = ``{``'``CLIENT_DONATION``'``:` `'``https://sandbox.google.c``...``
| __PRODUCTION_URLS = ``{``'``CLIENT_DONATION``'``:` `'``https://checkout.goog``...``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, vendor_id, merchant_key, is_sandbox=True, currency=`'``USD``'`) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

Class Variable Details | [hide private]

  ### __SANDBOX_URLS Value:
      {'CLIENT_DONATION': 'https://sandbox.google.com/checkout/api/checkout/
      v2/checkout/Donations/%s',
       'CLIENT_POST_CART': 'https://sandbox.google.com/checkout/api/checkout
      /v2/checkout/Merchant/%s',
       'DONATION_BUTTON': 'https://sandbox.google.com/checkout/buttons/donat
      ion.gif?merchant_id=%s&w=160&h=43&style=white&variant=text',
       'MERCHANT_BUTTON': 'https://sandbox.google.com/checkout/buttons/check
      out.gif?merchant_id=%s&w=160&h=43&style=white&variant=text',
      ...

  ### __PRODUCTION_URLS Value:
      {'CLIENT_DONATION': 'https://checkout.google.com/api/checkout/v2/check
      out/Donations/%s',
       'CLIENT_POST_CART': 'https://checkout.google.com/api/checkout/v2/chec
      kout/Merchant/%s',
       'DONATION_BUTTON': 'https://checkout.google.com/buttons/donation.gif?
      merchant_id=%s&w=160&h=43&style=white&variant=text',
       'MERCHANT_BUTTON': 'https://checkout.google.com/buttons/checkout.gif?
      merchant_id=%s&w=160&h=43&style=white&variant=text',
      ...